summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Makefile3
-rwxr-xr-xmkreleasehdr.sh2
-rw-r--r--redis.c1
3 files changed, 2 insertions, 4 deletions
diff --git a/Makefile b/Makefile
index 38b8448da..96dddd69e 100644
--- a/Makefile
+++ b/Makefile
@@ -48,8 +48,7 @@ redis-check-dump.o: redis-check-dump.c lzf.h
redis-cli.o: redis-cli.c fmacros.h anet.h sds.h adlist.h zmalloc.h \
linenoise.h
redis.o: redis.c fmacros.h config.h redis.h ae.h sds.h anet.h dict.h \
- adlist.h zmalloc.h lzf.h pqsort.h zipmap.h ziplist.h sha1.h release.h \
- staticsymbols.h
+ adlist.h zmalloc.h lzf.h pqsort.h zipmap.h ziplist.h sha1.h staticsymbols.h
release.o: release.c release.h
sds.o: sds.c sds.h zmalloc.h
sha1.o: sha1.c sha1.h
diff --git a/redis.c b/redis.c
index 8f5e8f47f..3fe9af1c7 100644
--- a/redis.c
+++ b/redis.c
@@ -77,7 +77,6 @@
#include "zipmap.h" /* Compact dictionary-alike data structure */
#include "ziplist.h" /* Compact list data structure */
#include "sha1.h" /* SHA1 is used for DEBUG DIGEST */
-#include "release.h" /* Release and/or git repository information */
/* Error codes */
#define REDIS_OK 0
diff --git a/mkreleasehdr.sh b/mkreleasehdr.sh
index 45f5173a4..30984160e 100755
--- a/mkreleasehdr.sh
+++ b/mkreleasehdr.sh
@@ -6,4 +6,4 @@ test -f release.h || touch release.h
(cat release.h | grep DIRTY | grep $GIT_DIRTY) && exit 0 # Already uptodate
echo "#define REDIS_GIT_SHA1 \"$GIT_SHA1\"" > release.h
echo "#define REDIS_GIT_DIRTY \"$GIT_DIRTY\"" >> release.h
-touch redis.c # Force recompile of redis.c
+touch release.c # Force recompile of release.c